@@ -1,4 +1,4 @@
-from django_registration.backends.activation.views import ActivationView
+from registration.backends.default.views import ActivationView
 from next_url_mixin.mixin import NextUrlMixin
 
 
